;; Generated package description from soap-client.el
(define-package "soap-client" "3.1.2" "Access SOAP web services" '((cl-lib "0.6.1")) :url "http://elpa.gnu.org/packages/soap-client.html" :keywords '("soap" "web-services" "comm" "hypermedia"))
